@@ -1,7 +1,8 @@
 context("dataset_suggest")
 
-tt <- dataset_suggest(query="Amazon", type="OCCURRENCE")
 test_that("type query returns the correct class", {
+  skip_on_cran()
+  tt <- dataset_suggest(query="Amazon", type="OCCURRENCE")
   expect_is(tt, "data.frame")
   expect_is(tt[1,1], "character")
 })
@@ -9,23 +10,26 @@ test_that("type query returns the correct class", {
 
 # Fulltext search for all datasets having the word "amsterdam" somewhere in 
 # its metadata (title, description, etc).
-tt <- dataset_suggest(query="amsterdam")
 test_that("search query returns the correct class", {
+  skip_on_cran()
+  tt <- dataset_suggest(query="amsterdam")
   expect_is(tt, "data.frame")
   expect_is(tt$title, "character")
   expect_is(tt$title[[1]], "character")
 })
 
 # Limited search
-tt <- dataset_suggest(type="OCCURRENCE", limit=2)
 test_that("limited search returns the correct class", {
+  skip_on_cran()
+  tt <- dataset_suggest(type="OCCURRENCE", limit=2)
   expect_is(tt, "data.frame")
   expect_is(tt[1,1], "character")
 })
 
 # Return just descriptions
-tt <- dataset_suggest(type="OCCURRENCE", description=TRUE)
 test_that("limited fields query returns the correct class", {
-  expect_is(tt, "list")
+  skip_on_cran()
+  tt <- dataset_suggest(type="OCCURRENCE", description=TRUE)
+  expect_is(tt, "character")
   expect_is(tt[[1]], "character")
 })
